@@ -1589,7 +1589,8 @@ class Str(Type):
 
             match = self.regex.match(norm)
             if match is None:
-                raise s_exc.BadTypeValu(name=self.name, valu=valu, mesg='regex does not match')
+                raise s_exc.BadTypeValu(name=self.name, valu=valu, regx=self.regex.pattern,
+                                        mesg=f'[{valu}] does not match [{self.regex.pattern}]')
 
             subs = match.groupdict()
             if subs:
@@ -1597,6 +1598,55 @@ class Str(Type):
 
         return norm, info
 
+taxonre = regex.compile('\w+')
+class Taxon(Str):
+
+    def postTypeInit(self):
+        Str.postTypeInit(self)
+        self.setNormFunc(str, self._normPyStr)
+
+    def _normForLift(self, valu):
+        return self.norm(valu)[0]
+
+    def _normPyStr(self, valu):
+        valu = valu.lower().strip()
+        parts = taxonre.findall(valu)
+        valu = '_'.join(parts)
+        if len(valu) == 0:
+            mesg = 'Each taxon must be non-zero length.'
+            raise s_exc.BadTypeValu(mesg=mesg)
+
+        return valu, {}
+
+class Taxonomy(Str):
+
+    def postTypeInit(self):
+        Str.postTypeInit(self)
+        self.setNormFunc(str, self._normPyStr)
+        self.setNormFunc(list, self._normPyList)
+        self.setNormFunc(tuple, self._normPyList)
+        self.taxon = self.modl.type('taxon')
+
+    def _normForLift(self, valu):
+        return self.norm(valu)[0]
+
+    def _normPyList(self, valu):
+
+        toks = [self.taxon.norm(v)[0] for v in valu]
+        subs = {
+            'base': toks[-1],
+            'depth': len(toks) - 1,
+        }
+
+        if len(toks) > 1:
+            subs['parent'] = '.'.join(toks[:-1]) + '.'
+
+        norm = '.'.join(toks) + '.'
+        return norm, {'subs': subs}
+
+    def _normPyStr(self, text):
+        return self._normPyList(text.strip().strip('.').split('.'))
+
 class Tag(Str):
 
     def postTypeInit(self):
@@ -1628,6 +1678,7 @@ class Tag(Str):
         toks = text.strip('#').split('.')
         return self._normPyList(toks)
 
+tagpartre = regex.compile('\w+')
 class TagPart(Str):
 
     def postTypeInit(self):
@@ -1636,7 +1687,8 @@ class TagPart(Str):
 
     def _normPyStr(self, valu):
         valu = valu.lower().strip()
-        valu = valu.replace('.', '_')
+        parts = tagpartre.findall(valu)
+        valu = '_'.join(parts)
         if len(valu) == 0:
             mesg = 'Each tag part must be non-zero length.'
             raise s_exc.BadTypeValu(mesg=mesg)
