@@ -45,7 +45,7 @@ class EconModule(s_module.CoreModule):
 
                 ('econ:currency', ('str', {'lower': True, 'strip': False}), {
                     'doc': 'The name of a system of money in general use',
-                    'ex': '2.20'}),
+                    'ex': 'usd'}),
 
                 ('econ:fin:exchange', ('guid', {}), {
                     'doc': 'A financial exchange where securities are traded.'}),
@@ -123,6 +123,9 @@ class EconModule(s_module.CoreModule):
                     ('paid:time', ('time', {}), {
                         'doc': 'The point in time where the purchase was paid in full.'}),
 
+                    ('settled', ('time', {}), {
+                        'doc': 'The point in time where the purchase was settled.'}),
+
                     ('campaign', ('ou:campaign', {}), {
                         'doc': 'The campaign that the purchase was in support of.'}),
 
@@ -147,6 +150,9 @@ class EconModule(s_module.CoreModule):
                     ('from:pay:card', ('econ:pay:card', {}), {
                         'doc': 'The payment card making the payment.'}),
 
+                    ('from:contract', ('ou:contract', {}), {
+                        'doc': 'A contract used as an aggregate payment source.'}),
+
                     ('from:coinaddr', ('crypto:currency:address', {}), {
                         'doc': 'The crypto currency address making the payment.'}),
 
@@ -159,6 +165,9 @@ class EconModule(s_module.CoreModule):
                     ('to:contact', ('ps:contact', {}), {
                         'doc': 'Contact information for the person/org being paid.'}),
 
+                    ('to:contract', ('ou:contract', {}), {
+                        'doc': 'A contract used as an aggregate payment destination.'}),
+
                     ('time', ('time', {}), {
                         'doc': 'The time the payment was processed.'}),
 
@@ -170,6 +179,9 @@ class EconModule(s_module.CoreModule):
 
                     ('currency', ('econ:currency', {}), {
                         'doc': 'The currency of the payment'}),
+
+                    ('memo', ('str', {}), {
+                        'doc': 'A small note specified by the payer common in financial transactions.'}),
                 )),
 
                 ('econ:fin:exchange', {}, (
