@@ -160,6 +160,13 @@ class FileModule(s_module.CoreModule):
 
     async def initCoreModule(self):
         self.model.prop('file:bytes:mime').onSet(self._onSetFileBytesMime)
+        self.core._setPropSetHook('file:bytes:sha256', self._hookFileBytesSha256)
+
+    async def _hookFileBytesSha256(self, node, prop, norm):
+        # this gets called post-norm and curv checks
+        if node.ndef[1].startswith('sha256:'):
+            mesg = "Can't change :sha256 on a file:bytes with sha256 based primary property."
+            raise s_exc.BadTypeValu(mesg=mesg)
 
     async def _onSetFileBytesMime(self, node, oldv):
         name = node.get('mime')
@@ -214,6 +221,26 @@ class FileModule(s_module.CoreModule):
                     'doc': 'Properties common to various microsoft office file formats.',
                     'interfaces': ('file:mime:meta',),
                 }),
+                ('file:mime:image', {
+                    'props': (
+                        ('desc', ('str', {}), {
+                            'doc': 'MIME specific description field extracted from metadata.'}),
+                        ('comment', ('str', {}), {
+                            'doc': 'MIME specific comment field extracted from metadata.'}),
+                        ('created', ('time', {}), {
+                            'doc': 'MIME specific creation timestamp extracted from metadata.'}),
+                        ('imageid', ('str', {}), {
+                            'doc': 'MIME specific unique identifier extracted from metadata.'}),
+                        ('author', ('ps:contact', {}), {
+                            'doc': 'MIME specific contact information extracted from metadata.'}),
+                        ('latlong', ('geo:latlong', {}), {
+                            'doc': 'MIME specific lat/long information extracted from metadata.'}),
+                        ('altitude', ('geo:altitude', {}), {
+                            'doc': 'MIME specific altitude information extracted from metadata.'}),
+                    ),
+                    'doc': 'Properties common to image file formats.',
+                    'interfaces': ('file:mime:meta',),
+                }),
             ),
 
             'types': (
@@ -255,6 +282,26 @@ class FileModule(s_module.CoreModule):
                     'interfaces': ('file:mime:meta',),
                 }),
 
+                ('file:mime:jpg', ('guid', {}), {
+                    'doc': 'The GUID of a set of mime metadata for a .jpg file.',
+                    'interfaces': ('file:mime:image',),
+                }),
+
+                ('file:mime:tif', ('guid', {}), {
+                    'doc': 'The GUID of a set of mime metadata for a .tif file.',
+                    'interfaces': ('file:mime:image',),
+                }),
+
+                ('file:mime:gif', ('guid', {}), {
+                    'doc': 'The GUID of a set of mime metadata for a .gif file.',
+                    'interfaces': ('file:mime:image',),
+                }),
+
+                ('file:mime:png', ('guid', {}), {
+                    'doc': 'The GUID of a set of mime metadata for a .png file.',
+                    'interfaces': ('file:mime:image',),
+                }),
+
                 ('file:mime:pe:section', ('comp', {'fields': (
                         ('file', 'file:bytes'),
                         ('name', 'str'),
@@ -305,20 +352,15 @@ class FileModule(s_module.CoreModule):
 
                 ('file:bytes', {}, (
 
-                    ('size', ('int', {}), {
-                        'doc': 'The file size in bytes.'}),
+                    ('size', ('int', {}), {'doc': 'The file size in bytes.'}),
 
-                    ('md5', ('hash:md5', {}), {'ro': True,
-                                               'doc': 'The md5 hash of the file.'}),
+                    ('md5', ('hash:md5', {}), {'doc': 'The md5 hash of the file.'}),
 
-                    ('sha1', ('hash:sha1', {}), {'ro': True,
-                                                 'doc': 'The sha1 hash of the file.'}),
+                    ('sha1', ('hash:sha1', {}), {'doc': 'The sha1 hash of the file.'}),
 
-                    ('sha256', ('hash:sha256', {}), {'ro': True,
-                                                     'doc': 'The sha256 hash of the file.'}),
+                    ('sha256', ('hash:sha256', {}), {'doc': 'The sha256 hash of the file.'}),
 
-                    ('sha512', ('hash:sha512', {}), {'ro': True,
-                                                     'doc': 'The sha512 hash of the file.'}),
+                    ('sha512', ('hash:sha512', {}), {'doc': 'The sha512 hash of the file.'}),
 
                     ('name', ('file:base', {}), {
                         'doc': 'The best known base name for the file.'}),
@@ -370,6 +412,11 @@ class FileModule(s_module.CoreModule):
                 ('file:mime:msxls', {}, ()),
                 ('file:mime:msppt', {}, ()),
 
+                ('file:mime:jpg', {}, ()),
+                ('file:mime:tif', {}, ()),
+                ('file:mime:gif', {}, ()),
+                ('file:mime:png', {}, ()),
+
                 ('file:mime:rtf', {}, (
                     ('guid', ('guid', {}), {
                         'doc': 'The parsed GUID embedded in the .rtf file.'}),
