@@ -1,4 +1,5 @@
 import os
+import subprocess
 
 import yaml
 
@@ -106,6 +107,15 @@ class CommonTest(s_t_utils.SynTest):
             retn = tuple(s_common.listdir(dirn, glob='*.txt'))
             self.eq(retn, ((path,)))
 
+            # getDirSize: check against du
+            real, appr = s_common.getDirSize(dirn)
+            durealstr = subprocess.check_output(['du', '-B', '1', '-s', dirn])
+            dureal = int(durealstr.split()[0])
+            duapprstr = subprocess.check_output(['du', '-bs', dirn])
+            duappr = int(duapprstr.split()[0])
+            self.eq(dureal, real)
+            self.eq(duappr, appr)
+
     def test_common_intify(self):
         self.eq(s_common.intify(20), 20)
         self.eq(s_common.intify("20"), 20)
@@ -271,6 +281,19 @@ class CommonTest(s_t_utils.SynTest):
             self.false(s_common.envbool('SYN_FOO'))
             self.false(s_common.envbool('SYN_BAR'))
 
+    def test_normlog(self):
+        self.eq(10, s_common.normLogLevel(' 10 '))
+        self.eq(10, s_common.normLogLevel(10))
+        self.eq(20, s_common.normLogLevel(' inFo\n'))
+        with self.raises(s_exc.BadArg):
+            s_common.normLogLevel(100)
+        with self.raises(s_exc.BadArg):
+            s_common.normLogLevel('BEEP')
+        with self.raises(s_exc.BadArg):
+            s_common.normLogLevel('12')
+        with self.raises(s_exc.BadArg):
+            s_common.normLogLevel({'key': 'newp'})
+
     async def test_merggenr(self):
         async def asyncl(data):
             for item in data:
