@@ -445,7 +445,7 @@ class TestModule(s_module.CoreModule):
         for name in items:
             await snap.addNode('test:str', name)
 
-    async def _testRuntLift(self, full, valu=None, cmpr=None):
+    async def _testRuntLift(self, full, valu=None, cmpr=None, view=None):
 
         now = s_common.now()
         modl = self.core.model
@@ -667,14 +667,21 @@ class AsyncStreamEvent(io.StringIO, asyncio.Event):
 
 class HttpReflector(s_httpapi.Handler):
     '''Test handler which reflects get/post data back to the caller'''
-    async def get(self):
-        resp = {}
+
+    def _decode_params(self):
+        d = collections.defaultdict(list)
         if self.request.arguments:
-            d = collections.defaultdict(list)
-            resp['params'] = d
             for k, items in self.request.arguments.items():
                 for v in items:
                     d[k].append(v.decode())
+        return d
+
+    async def get(self):
+        resp = {}
+        params = self._decode_params()
+        if params:
+            resp['params'] = params
+
         resp['headers'] = dict(self.request.headers)
         resp['path'] = self.request.path
 
@@ -687,18 +694,30 @@ class HttpReflector(s_httpapi.Handler):
 
     async def post(self):
         resp = {}
-        if self.request.arguments:
-            d = collections.defaultdict(list)
-            resp['params'] = d
-            for k, items in self.request.arguments.items():
-                for v in items:
-                    d[k].append(v.decode())
+        params = self._decode_params()
+        if params:
+            resp['params'] = params
+
         resp['headers'] = dict(self.request.headers)
         resp['path'] = self.request.path
+
         if self.request.body:
             resp['body'] = s_common.enbase64(self.request.body)
         self.sendRestRetn(resp)
 
+    async def head(self):
+        params = self._decode_params()
+        redirect = params.get('redirect')
+        self.add_header('Head', '1')
+
+        if redirect:
+            self.add_header('Redirected', '1')
+            self.redirect(redirect[0])
+            return
+
+        self.set_status(200)
+        return
+
 s_task.vardefault('applynest', lambda: None)
 
 async def _doubleapply(self, indx, item):
@@ -755,6 +774,11 @@ class SynTest(unittest.TestCase):
         if diff:
             logger.warning('form(%s): untested properties: %s', node.form.name, diff)
 
+    async def checkNodes(self, core, ndefs):
+        for ndef in ndefs:
+            node = await core.nodes('', opts={'ndefs': (ndef,)})
+            self.len(1, node)
+
     def worker(func, *args, **kwargs):
         '''
         Fire a worker thread to run the given func(*args,**kwargs)
@@ -921,14 +945,18 @@ class SynTest(unittest.TestCase):
                         mock.MagicMock(return_value=None)) as patch:  # type: mock.MagicMock
             yield patch
 
-    @contextlib.contextmanager
-    def withSetLoggingMock(self):
+    @contextlib.asynccontextmanager
+    async def withSetLoggingMock(self):
         '''
         Context manager to mock calls to the setlogging function to avoid unittests calling logging.basicconfig.
 
         Returns:
             mock.MagicMock: Yields a mock.MagikMock object.
         '''
+        # Since the setlogging routine is used in the forkserver initializer,
+        # we need to make sure we've initialized our worker prior to mocking
+        self.eq(1, await s_coro.forked(int, '1'))
+
         with mock.patch('synapse.common.setlogging',
                         mock.MagicMock(return_value=dict())) as patch:  # type: mock.MagicMock
             yield patch
@@ -1077,6 +1105,7 @@ class SynTest(unittest.TestCase):
         '''
         async with self.getTestCore(conf=conf, dirn=dirn) as core:
             core.conf['storm:log'] = True
+            core.stormlog = True
             async with core.getLocalProxy() as prox:
                 yield core, prox
 
